==> pyppms-1.1.0.dev0-py3-none-any.whl: pyppms/user.py <==
"""Module representing user objects in PPMS."""

import logging

from .common import dict_from_single_response

LOG = logging.getLogger(__name__)


class PpmsUser:

    """Object representing a user in PPMS.

    Attributes
    ----------
    username : str
        The user's account / login name in PPMS.
    email : str
        The user's email address.
    fullname : str
        The full name ("``<LASTNAME> <GIVENNAME>``") of the user in PPMS, falling back
        to the ``username`` attribute if empty.
    ppms_group : str
        The user's PPMS group, may be empty ("").
    active : bool
        The ``active`` state of the user account in PPMS, by default True.
    """

    # TODO: merge the alternative constructor(s) into __init__() (where applicable)

    def __init__(self, username, email, fullname="", ppms_group="", active=True):
        """Initialize the user object.

        Parameters
        ----------
        username : str
            The user's account / login name for PPMS.
        email : str
            The user's email address.
        fullname : str, optional
            The full name ("<LASTNAME> <GIVENNAME>") of the user in PPMS, by
            default empty ("").
        ppms_group : str, optional
            The user's PPMS group, by default empty ("").
        active : bool, optional
            The state of the user account in PPMS, by default True.
        """
        self.username = "%s" % username
        self.email = str(email)
        self.active = active
        self.ppms_group = ppms_group
        self._fullname = "%s" % fullname

        LOG.debug(
            "PpmsUser initialized: username=[%s], email=[%s], ppms_group=[%s], "
            "fullname=[%s], active=[%s]",
            self.username,
            self.email,
            self.ppms_group,
            self._fullname,
            self.active,
        )

    @classmethod
    def from_response(cls, response_text):
        """Alternative constructor using the text from the PUMAPI response.

        Parameters
        ----------
        response_text : str
            The text returned by a PUMAP `getuser` call.

        Returns
        -------
        PpmsUser
            The object constructed with the details contained in the PUMAPI
            response text.

        Raises
        ------
        ValueError
            Raised in case parsing the PUMAPI response data fails.
        """
        details = dict_from_single_response(response_text, graceful=True)

        user = cls(
            username=details["login"],
            email=details["email"],
            fullname=details["lname"] + " " + details["fname"],
            ppms_group=details["unitlogin"],
            active=details["active"],
        )
        return user

    @property
    def fullname(self):
        """The user's full name, falling back to the username if empty.

        Returns
        -------
        str
            The full name ("<LASTNAME> <GIVENNAME>") of the user in PPMS, or the
            user accocunt name if the former one is empty.
        """
        if self._fullname == "":
            return self.username

        return self._fullname

    def details(self):
        """Generate a string with details on the user object."""
        return "username: %s, email: %s, fullname: %s, ppms_group: %s, active: %s" % (
            self.username,
            self.email,
            self.fullname,
            self.ppms_group,
            self.active,
        )

    def __str__(self):
        return str(self.username)

==> pyppms-2.1.1.dev0-py3-none-any.whl: pyppms/user.py <==
"""Module representing user objects in PPMS."""

import logging

from .common import dict_from_single_response

LOG = logging.getLogger(__name__)


class PpmsUser:

    """Object representing a user in PPMS.

    Attributes
    ----------
    username : str
        The user's account / login name in PPMS.
    email : str
        The user's email address.
    fullname : str
        The full name ("``<LASTNAME> <GIVENNAME>``") of the user in PPMS, falling back
        to the ``username`` attribute if empty.
    ppms_group : str
        The user's PPMS group, may be empty ("").
    active : bool
        The ``active`` state of the user account in PPMS, by default True.
    """

    def __init__(self, response_text):
        """Initialize the user object.

        Parameters
        ----------
        response_text : str
            The text returned by a PUMAP `getuser` call.
        """
        details = dict_from_single_response(response_text, graceful=True)

        self.username = str(details["login"])
        self.email = str(details["email"])
        self.active = details["active"]
        self.ppms_group = details["unitlogin"]
        self._fullname = f'{details["lname"]} {details["fname"]}'

        LOG.debug(
            "PpmsUser initialized: username=[%s], email=[%s], ppms_group=[%s], "
            "fullname=[%s], active=[%s]",
            self.username,
            self.email,
            self.ppms_group,
            self._fullname,
            self.active,
        )

    @property
    def fullname(self):
        """The user's full name, falling back to the username if empty.

        Returns
        -------
        str
            The full name ("<LASTNAME> <GIVENNAME>") of the user in PPMS, or the
            user accocunt name if the former one is empty.
        """
        if self._fullname == "":
            return self.username

        return self._fullname

    def details(self):
        """Generate a string with details on the user object."""
        return (
            f"username: {self.username}, "
            f"email: {self.email}, "
            f"fullname: {self.fullname}, "
            f"ppms_group: {self.ppms_group}, "
            f"active: {self.active}"
        )

    def __str__(self):
        return str(self.username)
